==> haskell-vector-sized-1.6.1-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-sized
version:              1.6.1
visibility:           public
id:                   vector-sized-1.6.1-1vxJEZe2Jpg5yiSSzzQNpm
key:                  vector-sized-1.6.1-1vxJEZe2Jpg5yiSSzzQNpm
license:              BSD-3-Clause
copyright:            2016 Ellie Hermaszewska
maintainer:           whats.our.vector.victor@monoid.al
author:               Ellie Hermaszewska
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  cce259db86c54544e54fb46523db4e33
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

import-dirs:          /usr/lib/ghc-9.2.8/site-local/vector-sized-1.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vector-sized-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-sized
hs-libraries:         HSvector-sized-1.6.1-1vxJEZe2Jpg5yiSSzzQNpm
depends:
    adjunctions-4.4.2-ArJqvIz7v91Lf8ZLBi2rfM base-4.16.4.0
    binary-0.8.9.0 comonad-5.0.8-ECGCXO0IDm6CmzMMLQMWdW deepseq-1.4.6.1
    distributive-0.6.2.1-Bx2F0eAgMfT82Es2djCngR
    finite-typelits-0.1.6.0-DyB119aaOWUGjC0ww05krb
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    indexed-list-literals-0.2.1.3-6f99KYipUmaHj0deE1bqT4
    indexed-traversable-0.1.3-1Qv6lMYD85cCoJPVws66xH
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-sized-1.6.1-11-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-sized.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-sized
version:              1.6.1
visibility:           public
id:                   vector-sized-1.6.1-4b5NSF1fnPWJvIXf0jbdHe
key:                  vector-sized-1.6.1-4b5NSF1fnPWJvIXf0jbdHe
license:              BSD-3-Clause
copyright:            2016 Ellie Hermaszewska
maintainer:           whats.our.vector.victor@monoid.al
author:               Ellie Hermaszewska
homepage:             https://github.com/expipiplus1/vector-sized#readme
synopsis:             Size tagged vectors
description:          Please see README.md
category:             Data
abi:                  d93769ec3530ff9a5d05a5399de5db8a
exposed:              True
exposed-modules:
    Data.Vector.Generic.Mutable.Sized
    Data.Vector.Generic.Mutable.Sized.Internal
    Data.Vector.Generic.Sized Data.Vector.Generic.Sized.Internal
    Data.Vector.Mutable.Sized Data.Vector.Primitive.Mutable.Sized
    Data.Vector.Primitive.Sized Data.Vector.Sized
    Data.Vector.Storable.Mutable.Sized Data.Vector.Storable.Sized
    Data.Vector.Unboxed.Mutable.Sized Data.Vector.Unboxed.Sized

import-dirs:          /usr/lib/ghc-9.2.8/site-local/vector-sized-1.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/vector-sized-1.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-sized
hs-libraries:         HSvector-sized-1.6.1-4b5NSF1fnPWJvIXf0jbdHe
depends:
    adjunctions-4.4.2-KlpDvJ0DKsxIUTIJV0ALg7 base-4.16.4.0
    binary-0.8.9.0 comonad-5.0.8-IfNPtpIcmZzDrqwKpkhall deepseq-1.4.6.1
    distributive-0.6.2.1-Bx2F0eAgMfT82Es2djCngR
    finite-typelits-0.1.6.0-DyB119aaOWUGjC0ww05krb
    hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
    indexed-list-literals-0.2.1.3-6f99KYipUmaHj0deE1bqT4
    indexed-traversable-0.1.3-1PlU7tXvpJn7cw4eX0aHON
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:
    /usr/share/doc/haskell-vector-sized/html/vector-sized.haddock

haddock-html:         /usr/share/doc/haskell-vector-sized/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
